@@ -12,23 +12,7 @@
  * Copyright (c) 2005-2007 Daylon Graphics Ltd.
  * Copyright (c) 2007-2013, Even Rouault <even dot rouault at spatialys.com>
  *
- * Permission is hereby granted, free of charge, to any person obtaining a
- * copy of this software and associated documentation files (the "Software"),
- * to deal in the Software without restriction, including without limitation
- * the rights to use, copy, modify, merge, publish, distribute, sublicense,
- * and/or sell copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included
- * in all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
- * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
- * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
- * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
- * DEALINGS IN THE SOFTWARE.
+ * SPDX-License-Identifier: MIT
  ****************************************************************************/
 
 #include "gdal_frmts.h"
@@ -383,7 +367,7 @@ class digital_axis
 
   protected:
     int m_eStyle;
-    size_t m_fixedEnd;
+    int m_fixedEnd;
     double m_d[2];
 };
 
@@ -1460,7 +1444,7 @@ GDALDataset *LevellerDataset::Open(GDALOpenInfo *poOpenInfo)
         return nullptr;
 
     const int version = poOpenInfo->pabyHeader[4];
-    if (version < 4 || version > 9)
+    if (version < 4 || version > 12)
         return nullptr;
 
     /* -------------------------------------------------------------------- */
