@@ -7,23 +7,7 @@
  ******************************************************************************
  * Copyright (c) 2023, TileDB, Inc
  *
- * Permission is hereby granted, free of charge, to any person obtaining a
- * copy of this software and associated documentation files (the "Software"),
- * to deal in the Software without restriction, including without limitation
- * the rights to use, copy, modify, merge, publish, distribute, sublicense,
- * and/or sell copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included
- * in all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
- * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
- * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
- * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
- * DEALINGS IN THE SOFTWARE.
+ * SPDX-License-Identifier: MIT
  ****************************************************************************/
 
 #include "tiledbmultidim.h"
@@ -741,7 +725,7 @@ std::shared_ptr<TileDBArray> TileDBArray::OpenFromDisk(
                             {
                                 if (!osVal.empty())
                                     osVal += ',';
-                                osVal += CPLSPrintf("%.18g", dfVal);
+                                osVal += CPLSPrintf("%.17g", dfVal);
                             }
                             aosGridMappingKeyValues.AddNameValue(osKey.c_str(),
                                                                  osVal.c_str());
@@ -1297,6 +1281,11 @@ FillBlockSize(const std::vector<std::shared_ptr<GDALDimension>> &aoDimensions,
         case GDT_Int64:
             tiledb_dt = TILEDB_INT64;
             break;
+        case GDT_CFloat16:
+        case GDT_Float16:
+            // tileDB does not support float16
+            tiledb_dt = TILEDB_FLOAT32;
+            break;
         case GDT_CFloat32:
         case GDT_Float32:
             tiledb_dt = TILEDB_FLOAT32;
