@@ -29,6 +29,12 @@
 
 #define CRS_ATTRIBUTE_NAME "_CRS"
 
+const CPLCompressor *ZarrGetShuffleCompressor();
+const CPLCompressor *ZarrGetShuffleDecompressor();
+const CPLCompressor *ZarrGetQuantizeDecompressor();
+const CPLCompressor *ZarrGetTIFFDecompressor();
+const CPLCompressor *ZarrGetFixedScaleOffsetDecompressor();
+
 /************************************************************************/
 /*                            ZarrDataset                               */
 /************************************************************************/
@@ -64,6 +70,11 @@ class ZarrDataset final : public GDALDataset
                                int nBands, GDALDataType eType,
                                char **papszOptions);
 
+    static GDALDataset *CreateCopy(const char *, GDALDataset *, int,
+                                   char **papszOptions,
+                                   GDALProgressFunc pfnProgress,
+                                   void *pProgressData);
+
     const char *GetMetadataItem(const char *pszName,
                                 const char *pszDomain) override;
     char **GetMetadata(const char *pszDomain) override;
@@ -748,6 +759,7 @@ class ZarrArray CPL_NON_FINAL : public GDALPamMDArray
     const GDALExtendedDataType m_oType;
     const std::vector<DtypeElt> m_aoDtypeElts;
     const std::vector<GUInt64> m_anBlockSize;
+    CPLStringList m_aosStructuralInfo{};
     CPLJSONObject m_dtype{};
     GByte *m_pabyNoData = nullptr;
     std::string m_osDimSeparator{"."};
@@ -899,6 +911,11 @@ class ZarrArray CPL_NON_FINAL : public GDALPamMDArray
         return m_anBlockSize;
     }
 
+    CSLConstList GetStructuralInfo() const override
+    {
+        return m_aosStructuralInfo.List();
+    }
+
     const void *GetRawNoDataValue() const override
     {
         return m_pabyNoData;
@@ -1034,6 +1051,11 @@ class ZarrArray CPL_NON_FINAL : public GDALPamMDArray
 
     bool CacheTilePresence();
 
+    void SetStructuralInfo(const char *pszKey, const char *pszValue)
+    {
+        m_aosStructuralInfo.SetNameValue(pszKey, pszValue);
+    }
+
     static void DecodeSourceElt(const std::vector<DtypeElt> &elts,
                                 const GByte *pSrc, GByte *pDst);
 
@@ -1095,10 +1117,7 @@ class ZarrV2Array final : public ZarrArray
            const std::vector<DtypeElt> &aoDtypeElts,
            const std::vector<GUInt64> &anBlockSize, bool bFortranOrder);
 
-    void SetCompressorJson(const CPLJSONObject &oCompressor)
-    {
-        m_oCompressorJSon = oCompressor;
-    }
+    void SetCompressorJson(const CPLJSONObject &oCompressor);
 
     void SetCompressorDecompressor(const std::string &osDecompressorId,
                                    const CPLCompressor *psComp,
@@ -1109,10 +1128,7 @@ class ZarrV2Array final : public ZarrArray
         m_psDecompressor = psDecomp;
     }
 
-    void SetFilters(const CPLJSONArray &oFiltersArray)
-    {
-        m_oFiltersArray = oFiltersArray;
-    }
+    void SetFilters(const CPLJSONArray &oFiltersArray);
 
     void Flush() override;
 
@@ -1207,25 +1223,24 @@ class ZarrV3Codec CPL_NON_FINAL
 };
 
 /************************************************************************/
-/*                           ZarrV3CodecGZip                            */
+/*                      ZarrV3CodecAbstractCompressor                   */
 /************************************************************************/
 
-// Implements https://zarr-specs.readthedocs.io/en/latest/v3/codecs/gzip/v1.0.html
-class ZarrV3CodecGZip final : public ZarrV3Codec
+class ZarrV3CodecAbstractCompressor CPL_NON_FINAL : public ZarrV3Codec
 {
+  protected:
     CPLStringList m_aosCompressorOptions{};
     const CPLCompressor *m_pDecompressor = nullptr;
     const CPLCompressor *m_pCompressor = nullptr;
 
-    ZarrV3CodecGZip(const ZarrV3CodecGZip &) = delete;
-    ZarrV3CodecGZip &operator=(const ZarrV3CodecGZip &) = delete;
+    explicit ZarrV3CodecAbstractCompressor(const std::string &osName);
+
+    ZarrV3CodecAbstractCompressor(const ZarrV3CodecAbstractCompressor &) =
+        delete;
+    ZarrV3CodecAbstractCompressor &
+    operator=(const ZarrV3CodecAbstractCompressor &) = delete;
 
   public:
-    static constexpr const char *NAME = "gzip";
-
-    ZarrV3CodecGZip();
-    ~ZarrV3CodecGZip() override;
-
     IOType GetInputType() const override
     {
         return IOType::BYTES;
@@ -1236,6 +1251,24 @@ class ZarrV3CodecGZip final : public ZarrV3Codec
         return IOType::BYTES;
     }
 
+    bool Encode(const ZarrByteVectorQuickResize &abySrc,
+                ZarrByteVectorQuickResize &abyDst) const override;
+    bool Decode(const ZarrByteVectorQuickResize &abySrc,
+                ZarrByteVectorQuickResize &abyDst) const override;
+};
+
+/************************************************************************/
+/*                           ZarrV3CodecGZip                            */
+/************************************************************************/
+
+// Implements https://zarr-specs.readthedocs.io/en/latest/v3/codecs/gzip/v1.0.html
+class ZarrV3CodecGZip final : public ZarrV3CodecAbstractCompressor
+{
+  public:
+    static constexpr const char *NAME = "gzip";
+
+    ZarrV3CodecGZip();
+
     static CPLJSONObject GetConfiguration(int nLevel);
 
     bool
@@ -1244,11 +1277,6 @@ class ZarrV3CodecGZip final : public ZarrV3Codec
                           ZarrArrayMetadata &oOutputArrayMetadata) override;
 
     std::unique_ptr<ZarrV3Codec> Clone() const override;
-
-    bool Encode(const ZarrByteVectorQuickResize &abySrc,
-                ZarrByteVectorQuickResize &abyDst) const override;
-    bool Decode(const ZarrByteVectorQuickResize &abySrc,
-                ZarrByteVectorQuickResize &abyDst) const override;
 };
 
 /************************************************************************/
@@ -1256,30 +1284,12 @@ class ZarrV3CodecGZip final : public ZarrV3Codec
 /************************************************************************/
 
 // Implements https://zarr-specs.readthedocs.io/en/latest/v3/codecs/blosc/v1.0.html
-class ZarrV3CodecBlosc final : public ZarrV3Codec
+class ZarrV3CodecBlosc final : public ZarrV3CodecAbstractCompressor
 {
-    CPLStringList m_aosCompressorOptions{};
-    const CPLCompressor *m_pDecompressor = nullptr;
-    const CPLCompressor *m_pCompressor = nullptr;
-
-    ZarrV3CodecBlosc(const ZarrV3CodecBlosc &) = delete;
-    ZarrV3CodecBlosc &operator=(const ZarrV3CodecBlosc &) = delete;
-
   public:
     static constexpr const char *NAME = "blosc";
 
     ZarrV3CodecBlosc();
-    ~ZarrV3CodecBlosc() override;
-
-    IOType GetInputType() const override
-    {
-        return IOType::BYTES;
-    }
-
-    IOType GetOutputType() const override
-    {
-        return IOType::BYTES;
-    }
 
     static CPLJSONObject GetConfiguration(const char *cname, int clevel,
                                           const char *shuffle, int typesize,
@@ -1291,27 +1301,43 @@ class ZarrV3CodecBlosc final : public ZarrV3Codec
                           ZarrArrayMetadata &oOutputArrayMetadata) override;
 
     std::unique_ptr<ZarrV3Codec> Clone() const override;
-
-    bool Encode(const ZarrByteVectorQuickResize &abySrc,
-                ZarrByteVectorQuickResize &abyDst) const override;
-    bool Decode(const ZarrByteVectorQuickResize &abySrc,
-                ZarrByteVectorQuickResize &abyDst) const override;
 };
 
 /************************************************************************/
-/*                           ZarrV3CodecEndian                          */
+/*                          ZarrV3CodecZstd                             */
 /************************************************************************/
 
-// Implements https://zarr-specs.readthedocs.io/en/latest/v3/codecs/endian/v1.0.html
-class ZarrV3CodecEndian final : public ZarrV3Codec
+// Implements https://github.com/zarr-developers/zarr-specs/pull/256
+class ZarrV3CodecZstd final : public ZarrV3CodecAbstractCompressor
+{
+  public:
+    static constexpr const char *NAME = "zstd";
+
+    ZarrV3CodecZstd();
+
+    static CPLJSONObject GetConfiguration(int level, bool checksum);
+
+    bool
+    InitFromConfiguration(const CPLJSONObject &configuration,
+                          const ZarrArrayMetadata &oInputArrayMetadata,
+                          ZarrArrayMetadata &oOutputArrayMetadata) override;
+
+    std::unique_ptr<ZarrV3Codec> Clone() const override;
+};
+
+/************************************************************************/
+/*                           ZarrV3CodecBytes                           */
+/************************************************************************/
+
+// Implements https://zarr-specs.readthedocs.io/en/latest/v3/codecs/bytes/v1.0.html
+class ZarrV3CodecBytes final : public ZarrV3Codec
 {
     bool m_bLittle = true;
 
   public:
-    static constexpr const char *NAME = "endian";
+    static constexpr const char *NAME = "bytes";
 
-    ZarrV3CodecEndian();
-    ~ZarrV3CodecEndian() override;
+    ZarrV3CodecBytes();
 
     IOType GetInputType() const override
     {
@@ -1374,7 +1400,6 @@ class ZarrV3CodecTranspose final : public ZarrV3Codec
     static constexpr const char *NAME = "transpose";
 
     ZarrV3CodecTranspose();
-    ~ZarrV3CodecTranspose() override;
 
     IOType GetInputType() const override
     {
