@@ -7,23 +7,7 @@
  ******************************************************************************
  * Copyright (c) 2023, Even Rouault <even dot rouault at spatialys.com>
  *
- * Permission is hereby granted, free of charge, to any person obtaining a
- * copy of this software and associated documentation files (the "Software"),
- * to deal in the Software without restriction, including without limitation
- * the rights to use, copy, modify, merge, publish, distribute, sublicense,
- * and/or sell copies of the Software, and to permit persons to whom the
- * Software is furnished to do so, subject to the following conditions:
- *
- * The above copyright notice and this permission notice shall be included
- * in all copies or substantial portions of the Software.
- *
- * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
- * OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
- * THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
- * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
- * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
- * DEALINGS IN THE SOFTWARE.
+ * SPDX-License-Identifier: MIT
  ****************************************************************************/
 
 #include "cpl_port.h"
@@ -37,6 +21,7 @@
 
 #include <algorithm>
 #include <cassert>
+#include <cmath>
 #include <limits>
 #include <new>
 #include <utility>
@@ -67,9 +52,9 @@ bool OGROpenFileGDBDataSource::OpenRaster(const GDALOpenInfo *poOpenInfo,
 
     FileGDBTable oTable;
 
-    const CPLString osBndFilename(CPLFormFilename(
+    const std::string osBndFilename(CPLFormFilenameSafe(
         m_osDirName, CPLSPrintf("a%08x.gdbtable", nBndIdx), nullptr));
-    if (!oTable.Open(osBndFilename, false))
+    if (!oTable.Open(osBndFilename.c_str(), false))
     {
         CPLError(CE_Failure, CPLE_AppDefined, "Cannot open table %s",
                  osBndTableName.c_str());
@@ -117,10 +102,14 @@ bool OGROpenFileGDBDataSource::OpenRaster(const GDALOpenInfo *poOpenInfo,
         return false;
     }
 
-    int iRow = 0;
+    int64_t iRow = 0;
     while (iRow < oTable.GetTotalRecordCount() &&
            (iRow = oTable.GetAndSelectNextNonEmptyRow(iRow)) >= 0)
     {
+        if (iRow >= INT32_MAX)
+        {
+            return false;
+        }
         auto psField = oTable.GetFieldValue(i_raster_id);
         if (!psField)
         {
@@ -137,7 +126,7 @@ bool OGROpenFileGDBDataSource::OpenRaster(const GDALOpenInfo *poOpenInfo,
             continue;
         }
 
-        const int nGDBRasterBandId = iRow + 1;
+        const int nGDBRasterBandId = static_cast<int>(iRow) + 1;
 
         psField = oTable.GetFieldValue(i_sequence_nbr);
         if (!psField)
@@ -465,9 +454,9 @@ bool OGROpenFileGDBDataSource::OpenRaster(const GDALOpenInfo *poOpenInfo,
 
             FileGDBTable oTableMain;
 
-            const CPLString osTableMain(CPLFormFilename(
+            const std::string osTableMain(CPLFormFilenameSafe(
                 m_osDirName, CPLSPrintf("a%08x.gdbtable", nTableIdx), nullptr));
-            if (oTableMain.Open(osTableMain, false))
+            if (oTableMain.Open(osTableMain.c_str(), false))
             {
                 const int iRasterFieldIdx = oTableMain.GetFieldIdx("RASTER");
                 if (iRasterFieldIdx >= 0)
@@ -715,7 +704,7 @@ bool OGROpenFileGDBDataSource::OpenRaster(const GDALOpenInfo *poOpenInfo,
             if (std::fabs(dfNoData) > std::numeric_limits<float>::max())
             {
                 CPLError(CE_Failure, CPLE_AppDefined,
-                         "Invalid nodata value %.18g for Float32", dfNoData);
+                         "Invalid nodata value %.17g for Float32", dfNoData);
                 return false;
             }
             bHasNoData = true;
@@ -758,7 +747,7 @@ bool OGROpenFileGDBDataSource::OpenRaster(const GDALOpenInfo *poOpenInfo,
                 dfNoData != static_cast<double>(static_cast<int64_t>(dfNoData)))
             {
                 CPLError(CE_Failure, CPLE_AppDefined,
-                         "Invalid nodata value %.18g for %s", dfNoData,
+                         "Invalid nodata value %.17g for %s", dfNoData,
                          GDALGetDataTypeName(eDT));
                 return false;
             }
@@ -901,8 +890,8 @@ void OGROpenFileGDBDataSource::GuessJPEGQuality(int nOverviewCount)
                 }
                 if (nJPEGSize)
                 {
-                    CPLString osTmpFilename;
-                    osTmpFilename.Printf("/vsimem/_openfilegdb/%p.jpg", this);
+                    const CPLString osTmpFilename(
+                        VSIMemGenerateHiddenFilename("openfilegdb.jpg"));
                     VSIFCloseL(VSIFileFromMemBuffer(
                         osTmpFilename.c_str(),
                         const_cast<GByte *>(pabyData + nJPEGOffset), nJPEGSize,
@@ -1546,8 +1535,8 @@ CPLErr GDALOpenFileGDBRasterBand::IReadBlock(int nBlockXOff, int nBlockYOff,
                 return CE_Failure;
             }
 
-            CPLString osTmpFilename;
-            osTmpFilename.Printf("/vsimem/_openfilegdb/%p.jpg", this);
+            const CPLString osTmpFilename(
+                VSIMemGenerateHiddenFilename("openfilegdb.jpg"));
             VSIFCloseL(VSIFileFromMemBuffer(
                 osTmpFilename.c_str(),
                 const_cast<GByte *>(pabyData + nJPEGOffset), nJPEGSize, false));
@@ -1669,8 +1658,8 @@ CPLErr GDALOpenFileGDBRasterBand::IReadBlock(int nBlockXOff, int nBlockYOff,
                 return CE_Failure;
             }
 
-            CPLString osTmpFilename;
-            osTmpFilename.Printf("/vsimem/_openfilegdb/%p.j2k", this);
+            const CPLString osTmpFilename(
+                VSIMemGenerateHiddenFilename("openfilegdb.j2k"));
             VSIFCloseL(VSIFileFromMemBuffer(
                 osTmpFilename.c_str(),
                 const_cast<GByte *>(pabyData + nJPEGOffset), nJPEGSize, false));
@@ -1896,7 +1885,7 @@ CPLErr GDALOpenFileGDBRasterBand::IReadBlock(int nBlockXOff, int nBlockYOff,
         {
             for (int x = 0; x < nBlockXSize; ++x)
             {
-                printf("%.18g ", // ok
+                printf("%.17g ", // ok
                        static_cast<double *>(pImage)[y * nBlockXSize + x]);
             }
             printf("\n"); // ok
